/* Define if you have the pcre library (-lpcre). */
#undef HAVE_LIBPCRE

/* Define if pcrelib version is 2.00 or greater */
#undef NEW_PCRE_COMPILE

/* Define if pcrelib version is 2.06 or greater */
#undef NEW_PCRE_EXEC

/* Define if tm_gmtoff is present in struct tm */
#undef HAVE_GMTOFF

/* Define if you have IPv6 */
#undef HAVE_IPV6

/* Define if you have BSD syslog without facilities */
#undef HAVE_OLD_SYSLOG
